@@ -1,5 +1,7 @@
 use crate::lib::script::*;
 
 pub fn install(cmd: &str) -> Result<(), Box<dyn std::error::Error>> {
-    run_cmd(&cmd)
+    run_cmd(&cmd)?;
+
+    Ok(())
 }
